EXPORTS
	__11TImCodecB64 @ 1 NONAME R3UNUSED ; TImCodecB64::TImCodecB64(void)
	ConvertHeaderFieldL__16CImConvertHeaderRC7TDesC16R5TDes8 @ 2 NONAME R3UNUSED ; CImConvertHeader::ConvertHeaderFieldL(TDesC16 const &, TDes8 &)
	DecodeAllHeaderFieldsL__16CImConvertHeaderR9CImHeader @ 3 NONAME R3UNUSED ; CImConvertHeader::DecodeAllHeaderFieldsL(CImHeader &)
	DecodeHeaderFieldL__16CImConvertHeaderRC6TDesC8R6TDes16 @ 4 NONAME R3UNUSED ; CImConvertHeader::DecodeHeaderFieldL(TDesC8 const &, TDes16 &)
	DecodeHeaderFieldL__16CImConvertHeaderRC7TDesC16R6TDes16 @ 5 NONAME R3UNUSED ; CImConvertHeader::DecodeHeaderFieldL(TDesC16 const &, TDes16 &)
	DecodeRichText__10TImCodecQPRC6TDesC8R6TDes16 @ 6 NONAME R3UNUSED ; TImCodecQP::DecodeRichText(TDesC8 const &, TDes16 &)
	Decode__10TImCodecQPRC6TDesC8R5TDes8 @ 7 NONAME R3UNUSED ; TImCodecQP::Decode(TDesC8 const &, TDes8 &)
	Decode__10TImCodecUURC6TDesC8R5TDes8 @ 8 NONAME R3UNUSED ; TImCodecUU::Decode(TDesC8 const &, TDes8 &)
	Decode__11TImCodecB64RC6TDesC8R5TDes8 @ 9 NONAME R3UNUSED ; TImCodecB64::Decode(TDesC8 const &, TDes8 &)
	Disconnect__20CImTextServerSession @ 10 NONAME R3UNUSED ; CImTextServerSession::Disconnect(void)
	Disconnect__20CImTextServerSessionR14TRequestStatus @ 11 NONAME R3UNUSED ; CImTextServerSession::Disconnect(TRequestStatus &)
	EncodeHeaderFieldL__16CImConvertHeaderRC7TDesC16R5TDes8Pt9CArrayFix1Z21TImHeaderEncodingInfoii @ 12 NONAME ; CImConvertHeader::EncodeHeaderFieldL(TDesC16 const &, TDes8 &, CArrayFix<TImHeaderEncodingInfo> *, int, int)
	EncodeHeaderFieldL__16CImConvertHeaderRC7TDesC16R5TDes8UiQ221TImHeaderEncodingInfo13TEncodingType @ 13 NONAME ; CImConvertHeader::EncodeHeaderFieldL(TDesC16 const &, TDes8 &, unsigned int, TImHeaderEncodingInfo::TEncodingType)
	EncodeRichText__10TImCodecQPRC6TDesC8R5TDes8 @ 14 NONAME R3UNUSED ; TImCodecQP::EncodeRichText(TDesC8 const &, TDes8 &)
	Encode__10TImCodecQPRC6TDesC8R5TDes8 @ 15 NONAME R3UNUSED ; TImCodecQP::Encode(TDesC8 const &, TDes8 &)
	Encode__10TImCodecUURC6TDesC8R5TDes8 @ 16 NONAME R3UNUSED ; TImCodecUU::Encode(TDesC8 const &, TDes8 &)
	Encode__11TImCodecB64RC6TDesC8R5TDes8 @ 17 NONAME R3UNUSED ; TImCodecB64::Encode(TDesC8 const &, TDes8 &)
	EvaluatePriorityText__10CImcvUtilsRC6TDesC8 @ 18 NONAME R3UNUSED ; CImcvUtils::EvaluatePriorityText(TDesC8 const &)
	EvaluateReturnReceiptFields__10CImcvUtilsRC6TDesC8 @ 19 NONAME R3UNUSED ; CImcvUtils::EvaluateReturnReceiptFields(TDesC8 const &)
	FindEncodedWord__16CImConvertHeaderR6TPtrC8RiN22 @ 20 NONAME ; CImConvertHeader::FindEncodedWord(TPtrC8 &, int &, int &, int &)
	GetCurrentTextLine__20CImTextServerSessionR5TDes8 @ 21 NONAME R3UNUSED ; CImTextServerSession::GetCurrentTextLine(TDes8 &)
	GetString__C13CImLogMessageR6TDes16i @ 22 NONAME R3UNUSED ; CImLogMessage::GetString(TDes16 &, int) const
	HeaderSize__14CImSendMessage @ 23 NONAME R3UNUSED ; CImSendMessage::HeaderSize(void)
	InitialiseL__14CImSendMessagel13TImSendMethodG5TTimeRC7TDesC16Ui21TImSMTPSendCopyToSelf @ 24 NONAME ; CImSendMessage::InitialiseL(long, TImSendMethod, TTime, TDesC16 const &, unsigned int, TImSMTPSendCopyToSelf)
	LocalName__20CImTextServerSession @ 25 NONAME R3UNUSED ; CImTextServerSession::LocalName(void)
	LogBase__13CImLogMessage @ 26 NONAME R3UNUSED ; CImLogMessage::LogBase(void)
	LogError__20CImTextServerSessionRC6TDesC8i @ 27 NONAME R3UNUSED ; CImTextServerSession::LogError(TDesC8 const &, int)
	LogEvent__13CImLogMessage @ 28 NONAME R3UNUSED ; CImLogMessage::LogEvent(void)
	LogText__20CImTextServerSessionRC6TDesC8 @ 29 NONAME R3UNUSED ; CImTextServerSession::LogText(TDesC8 const &)
	MessageCompleteL__14CImRecvConvert @ 30 NONAME R3UNUSED ; CImRecvConvert::MessageCompleteL(void)
	MessageCompleteL__14CImRecvConvertG14TMsvEmailEntry @ 31 NONAME R3UNUSED ; CImRecvConvert::MessageCompleteL(TMsvEmailEntry)
	MessageEntryDetailsL__14CImRecvConvert @ 32 NONAME R3UNUSED ; CImRecvConvert::MessageEntryDetailsL(void)
	NewLC__10CImcvUtils @ 33 NONAME R3UNUSED ; CImcvUtils::NewLC(void)
	NewLC__11CMimeParserR14CImRecvConvert @ 34 NONAME R3UNUSED ; CMimeParser::NewLC(CImRecvConvert &)
	NewLC__12CRfc822Token @ 35 NONAME R3UNUSED ; CRfc822Token::NewLC(void)
	NewLC__14CImRecvConvertR3RFsP15CMsvServerEntryG4TUidl @ 36 NONAME ; CImRecvConvert::NewLC(RFs &, CMsvServerEntry *, TUid, long)
	NewLC__14CImSendMessageR15CMsvServerEntry @ 37 NONAME R3UNUSED ; CImSendMessage::NewLC(CMsvServerEntry &)
	NewLC__20CImTextServerSessionQ220CImTextServerSession16TImOperationModeR11RSocketServ @ 38 NONAME R3UNUSED ; CImTextServerSession::NewLC(CImTextServerSession::TImOperationMode, RSocketServ &)
	NewL__10CImcvUtils @ 39 NONAME R3UNUSED ; CImcvUtils::NewL(void)
	NewL__11CMimeParserR14CImRecvConvert @ 40 NONAME R3UNUSED ; CMimeParser::NewL(CImRecvConvert &)
	NewL__13CImLogMessageR3RFsi @ 41 NONAME R3UNUSED ; CImLogMessage::NewL(RFs &, int)
	NewL__14CImRecvConvertR3RFsP15CMsvServerEntryG4TUidl @ 42 NONAME ; CImRecvConvert::NewL(RFs &, CMsvServerEntry *, TUid, long)
	NewL__14CImSendMessageR15CMsvServerEntry @ 43 NONAME R3UNUSED ; CImSendMessage::NewL(CMsvServerEntry &)
	NewL__16CImConvertHeaderR18CImConvertCharconv @ 44 NONAME R3UNUSED ; CImConvertHeader::NewL(CImConvertCharconv &)
	NewL__19CImCalculateMsgSizeR3RFsR15CMsvServerEntry @ 45 NONAME R3UNUSED ; CImCalculateMsgSize::NewL(RFs &, CMsvServerEntry &)
	NewL__20CImTextServerSession @ 46 NONAME R3UNUSED ; CImTextServerSession::NewL(void)
	NewL__20CImTextServerSessionR11RSocketServ @ 47 NONAME R3UNUSED ; CImTextServerSession::NewL(RSocketServ &)
	NextLineL__14CImSendMessageR5TDes8Ri @ 48 NONAME R3UNUSED ; CImSendMessage::NextLineL(TDes8 &, int &)
	ParseNextField__14CImRecvConvertRC6TDesC8 @ 49 NONAME R3UNUSED ; CImRecvConvert::ParseNextField(TDesC8 const &)
	ParseNextLineL__12CRfc822TokenRC6TDesC8 @ 50 NONAME R3UNUSED ; CRfc822Token::ParseNextLineL(TDesC8 const &)
	PriorityFieldsL__10CImcvUtilsR11CDesC8Array @ 51 NONAME R3UNUSED ; CImcvUtils::PriorityFieldsL(CDesC8Array &)
	QueueConnect__20CImTextServerSessionR14TRequestStatusRC7TDesC16iG9TCallBackUlii @ 52 NONAME ; CImTextServerSession::QueueConnect(TRequestStatus &, TDesC16 const &, int, TCallBack, unsigned long, int, int)
	QueueConnect__20CImTextServerSessionR14TRequestStatusRC7TDesC16iG9TCallBacki @ 53 NONAME ; CImTextServerSession::QueueConnect(TRequestStatus &, TDesC16 const &, int, TCallBack, int)
	QueueConnect__20CImTextServerSessionR14TRequestStatusRC7TDesC16iUlii @ 54 NONAME ; CImTextServerSession::QueueConnect(TRequestStatus &, TDesC16 const &, int, unsigned long, int, int)
	QueueConnect__20CImTextServerSessionR14TRequestStatusRC7TDesC16ii @ 55 NONAME ; CImTextServerSession::QueueConnect(TRequestStatus &, TDesC16 const &, int, int)
	QueueReceiveNextTextLine__20CImTextServerSessionR14TRequestStatus @ 56 NONAME R3UNUSED ; CImTextServerSession::QueueReceiveNextTextLine(TRequestStatus &)
	ReceiptFieldsL__10CImcvUtilsR11CDesC8Array @ 57 NONAME R3UNUSED ; CImcvUtils::ReceiptFieldsL(CDesC8Array &)
	ReceiveBinaryData__20CImTextServerSessionR14TRequestStatusR5TDes8i @ 58 NONAME ; CImTextServerSession::ReceiveBinaryData(TRequestStatus &, TDes8 &, int)
	Receive__20CImTextServerSessionR14TRequestStatusR5TDes8 @ 59 NONAME R3UNUSED ; CImTextServerSession::Receive(TRequestStatus &, TDes8 &)
	Receive__20CImTextServerSessionR5TDes8 @ 60 NONAME R3UNUSED ; CImTextServerSession::Receive(TDes8 &)
	ResetForHeadersL__14CImRecvConvert @ 61 NONAME R3UNUSED ; CImRecvConvert::ResetForHeadersL(void)
	ResetL__14CImRecvConvert @ 62 NONAME R3UNUSED ; CImRecvConvert::ResetL(void)
	Reset__12CRfc822Token @ 63 NONAME R3UNUSED ; CRfc822Token::Reset(void)
	Reset__13CImLogMessage @ 64 NONAME R3UNUSED ; CImLogMessage::Reset(void)
	Reset__14CImSendMessage @ 65 NONAME R3UNUSED ; CImSendMessage::Reset(void)
	SendPriorityFieldsL__10CImcvUtilsR11CDesC8Array @ 66 NONAME R3UNUSED ; CImcvUtils::SendPriorityFieldsL(CDesC8Array &)
	SendReceive__20CImTextServerSessionRC6TDesC8 @ 67 NONAME R3UNUSED ; CImTextServerSession::SendReceive(TDesC8 const &)
	SendReturnReceiptFieldsL__10CImcvUtilsR11CDesC8Array @ 68 NONAME R3UNUSED ; CImcvUtils::SendReturnReceiptFieldsL(CDesC8Array &)
	Send__20CImTextServerSessionGt11TRefByValue1ZC6TDesC8e @ 69 NONAME ; CImTextServerSession::Send(TRefByValue<TDesC8 const>,...)
	Send__20CImTextServerSessionR14TRequestStatusGt11TRefByValue1ZC6TDesC8e @ 70 NONAME ; CImTextServerSession::Send(TRequestStatus &, TRefByValue<TDesC8 const>,...)
	Send__20CImTextServerSessionR14TRequestStatusRC6TDesC8 @ 71 NONAME R3UNUSED ; CImTextServerSession::Send(TRequestStatus &, TDesC8 const &)
	Send__20CImTextServerSessionRC6TDesC8 @ 72 NONAME R3UNUSED ; CImTextServerSession::Send(TDesC8 const &)
	SetSecurity__20CImTextServerSessionii @ 73 NONAME R3UNUSED ; CImTextServerSession::SetSecurity(int, int)
	StartL__19CImCalculateMsgSizeR14TRequestStatusl13TImSendMethodR5TTimeRC7TDesC16Ui @ 74 NONAME ; CImCalculateMsgSize::StartL(TRequestStatus &, long, TImSendMethod, TTime &, TDesC16 const &, unsigned int)
	Start__13CImLogMessageiR14TRequestStatus @ 75 NONAME R3UNUSED ; CImLogMessage::Start(int, TRequestStatus &)
	"_._11CMimeParser" @ 76 NONAME R3UNUSED ; CMimeParser::~CMimeParser(void)
	"_._12CRfc822Token" @ 77 NONAME R3UNUSED ; CRfc822Token::~CRfc822Token(void)
	"_._14CImRecvConvert" @ 78 NONAME R3UNUSED ; CImRecvConvert::~CImRecvConvert(void)
	"_._19CImCalculateMsgSize" @ 79 NONAME R3UNUSED ; CImCalculateMsgSize::~CImCalculateMsgSize(void)
	__10TImCodecQP @ 80 NONAME R3UNUSED ; TImCodecQP::TImCodecQP(void)
	__10TImCodecUU @ 81 NONAME R3UNUSED ; TImCodecUU::TImCodecUU(void)
	BodySizeL__14CImSendMessage @ 82 NONAME R3UNUSED ; CImSendMessage::BodySizeL(void)
	SendQueueReceive__20CImTextServerSessionR14TRequestStatusGt11TRefByValue1ZC6TDesC8e @ 83 NONAME ; CImTextServerSession::SendQueueReceive(TRequestStatus &, TRefByValue<TDesC8 const>,...)
	SendQueueReceive__20CImTextServerSessionR14TRequestStatusRC6TDesC8 @ 84 NONAME R3UNUSED ; CImTextServerSession::SendQueueReceive(TRequestStatus &, TDesC8 const &)
	GetIAPBearer__20CImTextServerSessionRUl @ 85 NONAME R3UNUSED ; CImTextServerSession::GetIAPBearer(unsigned long &)
	GetIAPValue__20CImTextServerSessionRUl @ 86 NONAME R3UNUSED ; CImTextServerSession::GetIAPValue(unsigned long &)
	QueueConnectL__20CImTextServerSessionR14TRequestStatusRC7TDesC16iRC17CImIAPPreferencesi @ 87 NONAME ; CImTextServerSession::QueueConnectL(TRequestStatus &, TDesC16 const &, int, CImIAPPreferences const &, int)
	QueueConnect__20CImTextServerSessionR14TRequestStatusRC7TDesC16iG9TCallBackRC17CImIAPPreferencesii @ 88 NONAME ; CImTextServerSession::QueueConnect(TRequestStatus &, TDesC16 const &, int, TCallBack, CImIAPPreferences const &, int, int)
	QueueConnect__20CImTextServerSessionR14TRequestStatusRC7TDesC16iRC17CImIAPPreferencesii @ 89 NONAME ; CImTextServerSession::QueueConnect(TRequestStatus &, TDesC16 const &, int, CImIAPPreferences const &, int, int)
	DecodeNonMIMEHeaderFieldL__16CImConvertHeaderRC6TDesC8R6TDes16 @ 90 NONAME R3UNUSED ; CImConvertHeader::DecodeNonMIMEHeaderFieldL(TDesC8 const &, TDes16 &)
	InitialiseL__14CImSendMessagelG5TTimeRC7TDesC16RC24TImEmailTransformingInfo21TImSMTPSendCopyToSelf @ 91 NONAME ; CImSendMessage::InitialiseL(long, TTime, TDesC16 const &, TImEmailTransformingInfo const &, TImSMTPSendCopyToSelf)
	SetMessageType__16CImConvertHeaderi @ 92 NONAME R3UNUSED ; CImConvertHeader::SetMessageType(int)
	LeaveIfLowDiskL__16ImCheckDiskSpaceR3RFsi @ 93 NONAME R3UNUSED ; ImCheckDiskSpace::LeaveIfLowDiskL(RFs &, int)
	PerformLogging__20CImTextServerSessioni @ 94 NONAME R3UNUSED ; CImTextServerSession::PerformLogging(int)
	Initialise__11TImCodecB64 @ 95 NONAME R3UNUSED ; TImCodecB64::Initialise(void)
	SetSSLTLSResponseL__20CImTextServerSessionRC6TDesC8 @ 96 NONAME R3UNUSED ; CImTextServerSession::SetSSLTLSResponseL(TDesC8 const &)
	SSLQueueConnectL__20CImTextServerSessionR14TRequestStatusRC7TDesC16iRC17CImIAPPreferencesi @ 97 NONAME ; CImTextServerSession::SSLQueueConnectL(TRequestStatus &, TDesC16 const &, int, CImIAPPreferences const &, int)
	GetConnectionStage__20CImTextServerSession @ 98 NONAME R3UNUSED ; CImTextServerSession::GetConnectionStage(void)
	SetOverrideCharset__16CImConvertHeaderUi @ 99 NONAME R3UNUSED ; CImConvertHeader::SetOverrideCharset(unsigned int)
	OverrideCharset__C16CImConvertHeader @ 100 NONAME R3UNUSED ; CImConvertHeader::OverrideCharset(void) const
	DeletedAttachmentSize__14CImRecvConvert @ 101 NONAME R3UNUSED ; CImRecvConvert::DeletedAttachmentSize(void)
	WritePartialFooterL__14CImRecvConverti @ 102 NONAME R3UNUSED ; CImRecvConvert::WritePartialFooterL(int)
	MessageCompleteL__14CImRecvConverti @ 103 NONAME R3UNUSED ; CImRecvConvert::MessageCompleteL(int)
	GetRConnectionName__20CImTextServerSessionRt4TBuf1i128 @ 104 NONAME R3UNUSED ; CImTextServerSession::GetRConnectionName(TBuf<128> &)

